@@ -279,7 +279,7 @@ sub init {
       print STDERR "I: Got package name and version from debian/changelog.\n" if $opt_verbose;
    }
    else { 
-      exwerror "E: Not started from the trunk/PACKAGE directory.\n";
+      exwerror "E: Not started from the trunk/PACKAGE directory (debian/changelog garbled?).\n";
    }
    print "
    Package name: $package
